## cdist-type__start_on_boot(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__start_on_boot - Manage stuff to be started at boot

## 2. DESCRIPTION

This cdist type allows you to enable or disable stuff to be started at boot of your operating system.

Warning: This type has not been tested intensively and is not fully supported (i.e. gentoo and *bsd are not implemented).

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

state
  Either "present" or "absent", defaults to "present"

## 5. EXAMPLES

    # Ensure snmpd is started at boot
    __start_on_boot snmpd

    # Same, but more explicit
    __start_on_boot snmpd --state present

    # Ensure legacy configuration management will not be started
    __start_on_boot puppet --state absent

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__process(7)

## 7. COPYING

Copyright (C) 2012 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).